FocusReactParams class

Constructors

FocusReactParams({required Widget targetBuilder(FocusNode focusNode, TextEditingController textController), required FocusNode focusNode, required TextEditingController textController, required bool setTextToControllerOnSelect})
const

Properties

focusNode → FocusNode
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setTextToControllerOnSelect → bool
final
targetBuilder → Widget Function(FocusNode focusNode, TextEditingController textController)
final
textController → TextEditingController
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited